Filters

Struct Filters 

pub struct Filters { /* private fields */ }
General authorizations to access the iChen System via Open Protocol.

See this document for details.

Implementations

Source

impl Filters

pub const None: Filters

No rights.

pub const Status: Filters

Controller status update messages.

pub const Cycle: Filters

Cycle data messages.

pub const Mold: Filters

Mold data messages.

pub const Actions: Filters

Controller action messages.

pub const Alarms: Filters

Controller alarm messages.

pub const Audit: Filters

Controller audit trail of setting changes

pub const All: Filters

Administrator rights.

All implies Status + Cycle + Mold + Actions + Alarms + Audit

pub const JobCards: Filters

MIS/MES integration: Job scheduling messages.

pub const Operators: Filters

MIS/MES integration: User authorization messages.

pub const OPCUA: Filters

Industrial bus integration: Connect via OPC UA.

pub const fn empty() -> Filters

Returns an empty set of flags

pub const fn all() -> Filters

Returns the set containing all flags.

pub const fn bits(&self) -> u32

Returns the raw value of the flags currently stored.

pub fn from_bits(bits: u32) -> Option<Filters>

Convert from underlying bit representation, unless that representation contains bits that do not correspond to a flag.

pub const fn from_bits_truncate(bits: u32) -> Filters

Convert from underlying bit representation, dropping any bits that do not correspond to flags.

pub const fn is_empty(&self) -> bool

Returns true if no flags are currently stored.

pub const fn is_all(&self) -> bool

Returns true if all flags are currently set.

pub const fn intersects(&self, other: Filters) -> bool

Returns true if there are flags common to both self and other.

pub const fn contains(&self, other: Filters) -> bool

Returns true all of the flags in other are contained within self.

pub fn insert(&mut self, other: Filters)

Inserts the specified flags in-place.

pub fn remove(&mut self, other: Filters)

Removes the specified flags in-place.

pub fn toggle(&mut self, other: Filters)

Toggles the specified flags in-place.

pub fn set(&mut self, other: Filters, value: bool)

Inserts or removes the specified flags depending on the passed value.

Source

impl Filters

pub fn has(self, other: Self) -> bool

Is a particular set of filters set?

Examples
let f = Filters::Status + Filters::Audit + Filters::JobCards;
assert!(f.has(Filters::Status));
assert!(f.has(Filters::JobCards));
assert!(!f.has(Filters::All));
assert!(!f.has(Filters::OPCUA));
assert!(!f.has(Filters::Mold));